@@ -2,9 +2,15 @@
 Helper classes and functions for adapters
 """
 import datetime
+try:
+    import json  # Python 2.6+
+except ImportError:
+    import simplejson as json  # Python 2.5-
 
 from dateutil.relativedelta import relativedelta
 from dateutil.rrule import YEARLY, MONTHLY, DAILY, HOURLY, MINUTELY, SECONDLY
+from django.core.urlresolvers import reverse
+from django.http import HttpResponse
 from matplotlib.backends.backend_agg import FigureCanvasAgg as FigureCanvas
 from matplotlib.dates import AutoDateFormatter
 from matplotlib.dates import AutoDateLocator
@@ -14,10 +20,6 @@ from matplotlib.dates import rrulewrapper
 from matplotlib.figure import Figure
 from matplotlib.ticker import MaxNLocator
 
-from django.core.urlresolvers import reverse
-from django.http import HttpResponse
-import simplejson as json
-
 from lizard_map.matplotlib_settings import FONT_SIZE
 from lizard_map.matplotlib_settings import SCREEN_DPI
 
@@ -196,6 +198,8 @@ class Graph(object):
         self.legend_on_bottom_height = 0.0
         self.axes = self.figure.add_subplot(111)
         self.axes.grid(True)
+        self.fixup_axes()
+
         # Date range
         # self.axes.set_xlim(date2num((self.start_date, self.end_date)))
 
@@ -284,8 +288,6 @@ class Graph(object):
     def http_png(self):
         """Output plot to png. Also calculates size of plot and put 'now'
         line."""
-        self.fixup_axes()
-
         axes_left = self.left_label_width
         axes_bottom = (self.bottom_axis_location + self.x_label_height +
                        self.legend_on_bottom_height)
