@@ -1,12 +1,15 @@
 import itertools
 import logging
-import pkg_resources
+try:
+    import json  # Python 2.6+
+except ImportError:
+    import simplejson as json  # Python 2.5-
 
 from django.contrib.auth.models import User
-from django.db import models
 from django.core.urlresolvers import reverse
+from django.db import models
 from django.utils.translation import ugettext as _
-import simplejson as json
+import pkg_resources
 
 from lizard_map.adapter import parse_identifier_json
 
@@ -54,7 +57,7 @@ class Workspace(models.Model):
 
     name = models.CharField(max_length=80,
                             blank=True,
-                            default='workspace')
+                            default='Workspace')
     # TODO below: default extend values for NL?
     extent_north = models.FloatField(blank=True, null=True)
     extent_east = models.FloatField(blank=True, null=True)
@@ -73,6 +76,7 @@ class Workspace(models.Model):
 
 class WorkspaceItem(models.Model):
     """Can show things on a map based on configuration in a url."""
+
     class Meta:
         ordering = ['index']
         verbose_name = _("Workspace item")
@@ -133,7 +137,7 @@ class WorkspaceItem(models.Model):
 class WorkspaceCollage(models.Model):
     """A collage contains selections/locations from a workspace"""
     name = models.CharField(max_length=80,
-                            default='collage')
+                            default='Collage')
     workspace = models.ForeignKey(Workspace,
                                   related_name='collages')
 
@@ -281,6 +285,47 @@ class WorkspaceCollageSnippetGroup(models.Model):
                 pass
         return statistics
 
+    def values_table(self, start_date, end_date):
+        """
+        Calculates a table with each location as column, each row as
+        datetime. First row consist of column names. List of lists.
+        """
+        values_table = []
+
+        snippets = self.snippets.all()
+
+        # Add snippet names
+        values_table.append(['datetime'] + [snippet.name for snippet in snippets])
+
+        # Collect all data and found_dates.
+        found_dates = {}
+
+        # Snippet_values is a dict of (dicts of dicts {'datetime': .,
+        # 'value': .., 'unit': ..}, key: 'datetime').
+        snippet_values = {}
+
+        for snippet in snippets:
+            values = snippet.workspace_item.adapter.values(
+                identifier=snippet.identifier, start_date=start_date, end_date=end_date)
+            snippet_values[snippet.id] = {}
+            # Translate list into dict with dates.
+            for row in values:
+                snippet_values[snippet.id][row['datetime']] = row
+            found_dates.update(snippet_values[snippet.id])  # the value doesn't matter
+
+        found_dates_sorted = found_dates.keys()
+        found_dates_sorted.sort()
+
+        # Create each row.
+        for found_date in found_dates_sorted:
+            value_row = [found_date, ]
+            for snippet in snippets:
+                single_value = snippet_values[snippet.id].get(found_date, {})
+                value_row.append(single_value.get('value', None))
+            values_table.append(value_row)
+
+        return values_table
+
     def layout(self):
         """Returns layout properties of this snippet_group. Used in
         snippet.identifier['layout']"""
@@ -309,9 +354,9 @@ class WorkspaceCollageSnippetGroup(models.Model):
 class WorkspaceCollageSnippet(models.Model):
     """One snippet in a collage"""
     name = models.CharField(max_length=80,
-                            default='snippet')
+                            default='Snippet')
     shortname = models.CharField(max_length=80,
-                                 default='snippet',
+                                 default='Snippet',
                                  blank=True,
                                  null=True)
     snippet_group = models.ForeignKey(WorkspaceCollageSnippetGroup,
@@ -369,3 +414,92 @@ class WorkspaceCollageSnippet(models.Model):
     def set_identifier(self, identifier):
         """sets dictionary identifier to property identifier_json"""
         self.identifier_json = json.dumps(identifier).replace('"', '%22')
+
+
+class Color(models.Model):
+    """Simple color: alpha (optional), r, g, b.
+
+    Use values from 0 .. 255. Values are NOT checked!
+    """
+    a = models.IntegerField(default=255)
+    r = models.IntegerField()
+    g = models.IntegerField()
+    b = models.IntegerField()
+
+    def __unicode__(self):
+        return '(%0x)-%0x-%0x-%0x' % (self.a, self.r, self.g, self.b)
+
+
+class LegendManager(models.Manager):
+    """Implements extra function 'find'
+    """
+
+    def find(self, name):
+        """Tries to find matching legend. Second choice legend
+        'default'. If nothing found, return None"""
+
+        try:
+            found_legend = Legend.objects.get(descriptor__icontains=name)
+        except Legend.DoesNotExist:
+            try:
+                found_legend = Legend.objects.get(descriptor='default')
+            except Legend.DoesNotExist:
+                found_legend = None
+        return found_legend
+
+
+class Legend(models.Model):
+    """Simple lineair interpolated legend with min, max, color-min,
+    color-max, color < min, color > max, number of steps. Legends can
+    be found using the descriptor"""
+
+    descriptor = models.CharField(max_length=80)
+    min_value = models.FloatField(default=0)
+    max_value = models.FloatField(default=100)
+    steps = models.IntegerField(default=10)
+
+    min_color = models.ForeignKey(Color, related_name='min_colors')
+    max_color = models.ForeignKey(Color, related_name='max_colors')
+    too_low_color = models.ForeignKey(Color, related_name='too_low_colors')
+    too_high_color = models.ForeignKey(Color, related_name='too_high_color')
+
+    objects = LegendManager()
+
+    def __unicode__(self):
+        return self.descriptor
+
+    @property
+    def float_format(self):
+        delta = abs(self.max_value - self.min_value) / self.steps
+        if delta < 0.1:
+            return '%.3f'
+        if delta < 1:
+            return '%.2f'
+        if delta < 10:
+            return '%.1f'
+        return '%.0f'
+
+    def legend_values(self):
+        """Makes list of dictionaries: {'color': Color, 'low_value':
+        low value, 'high_value': high value}"""
+        result = []
+        value_per_step = (self.max_value - self.min_value) / self.steps
+        for step in range(self.steps):
+            try:
+                fraction = float(step) / (self.steps - 1)
+            except ZeroDivisionError:
+                fraction = 0
+            alpha = self.min_color.a * (1 - fraction) + self.max_color.a * fraction
+            red = self.min_color.r * (1 - fraction) + self.max_color.r * fraction
+            green = self.min_color.g * (1 - fraction) + self.max_color.g * fraction
+            blue = self.min_color.b * (1 - fraction) + self.max_color.b * fraction
+            color = Color(a=alpha, r=red, g=green, b=blue)
+
+            low_value = self.min_value + step * value_per_step
+            high_value = self.min_value + (step + 1) * value_per_step
+            result.append({
+                    'color': color,
+                    'low_value': low_value,
+                    'high_value': high_value
+                    })
+        return result
