@@ -1,8 +1,11 @@
 import StringIO
-import simplejson
+try:
+    import json  # Python 2.6+
+except ImportError:
+    import simplejson as json  # Python 2.5-
 
 import mapnik
-import PIL.Image
+import Image
 import csv
 from django.db.models import Max
 from django.http import HttpResponse
@@ -10,7 +13,6 @@ from django.template import RequestContext
 from django.shortcuts import get_object_or_404
 from django.shortcuts import render_to_response
 from django.views.decorators.cache import never_cache
-import simplejson as json
 
 from lizard_map import coordinates
 from lizard_map.adapter import parse_identifier_json
@@ -317,7 +319,7 @@ def popup_json(found, popup_id=None, hide_add_snippet=False, request=None):
               'html': result_html,
               'big': big_popup,
               }
-    return HttpResponse(simplejson.dumps(result))
+    return HttpResponse(json.dumps(result))
 
 
 def popup_collage_json(collage, popup_id, request=None):
@@ -351,7 +353,7 @@ def popup_collage_json(collage, popup_id, request=None):
               'html': result_html,
               'big': big_popup,
               }
-    return HttpResponse(simplejson.dumps(result))
+    return HttpResponse(json.dumps(result))
 
 
 # Collages stuff
@@ -364,12 +366,14 @@ def collage(request,
     """Render page with one collage"""
     date_range_form = DateRangeForm(
         current_start_end_dates(request, for_form=True))
+    show_table = request.GET.get('show_table', False)
     return render_to_response(
         template,
         {'collage': get_object_or_404(WorkspaceCollage, pk=collage_id),
          'editable': editable,
          'date_range_form': date_range_form,
-         'request': request},
+         'request': request,
+         'show_table': show_table},
         context_instance=RequestContext(request))
 
 
@@ -465,7 +469,7 @@ def workspace_item_image(request, workspace_item_id):
     identifier_list
     """
     identifier_json_list = request.GET.getlist('identifier')
-    identifier_list = [simplejson.loads(json) for json in identifier_json_list]
+    identifier_list = [json.loads(identifier_json) for identifier_json in identifier_json_list]
 
     width = request.GET.get('width')
     height = request.GET.get('height')
@@ -554,7 +558,7 @@ def wms(request, workspace_id):
     img = mapnik.Image(width, height)
     mapnik.render(mapnik_map, img)
     http_user_agent = request.META.get('HTTP_USER_AGENT', '')
-    rgba_image = PIL.Image.fromstring('RGBA', (width, height), img.tostring())
+    rgba_image = Image.fromstring('RGBA', (width, height), img.tostring())
     buf = StringIO.StringIO()
     if 'MSIE 6.0' in http_user_agent:
         imgPIL = rgba_image.convert('P')
@@ -622,6 +626,21 @@ def clickinfo(request, workspace_id):
 Export
 """
 
+def export_snippet_group_csv(request, snippet_group_id):
+    """
+    Creates a table with each location as column. Each row is a datetime.
+    """
+    snippet_group = WorkspaceCollageSnippetGroup.objects.get(pk=snippet_group_id)
+    start_date, end_date = current_start_end_dates(request)
+    table = snippet_group.values_table(start_date, end_date)
+
+    response = HttpResponse(mimetype='text/csv')
+    response['Content-Disposition'] = 'attachment; filename=export.csv'
+    writer = csv.writer(response)
+    for row in table:
+        writer.writerow(row)
+    return response
+
 
 def export_identifier_csv(request, workspace_item_id=None,
     identifier_json=None):
