@@ -3,7 +3,10 @@ import os
 from django.conf import settings
 from django.core.urlresolvers import reverse
 from django.template.loader import render_to_string
-import simplejson as json
+try:
+    import json  # Python 2.6+
+except ImportError:
+    import simplejson as json  # Python 2.5-
 
 from lizard_map.models import DEFAULT_WORKSPACES
 from lizard_map.models import ICON_ORIGINALS
@@ -184,7 +187,8 @@ class WorkspaceItemAdapter(object):
     def value_aggregate(self, identifier, aggregate_functions,
                         start_date, end_date):
         """
-        Aggregates values according to aggregate_functions.
+        Aggregates values according to aggregate_functions. Returns
+        dictionary with values.
         """
 
         raise NotImplementedError
@@ -385,3 +389,11 @@ class WorkspaceItemAdapter(object):
                 'snippet_group': snippet_group,
                 },
             )
+
+    def legend():
+        """
+        Returns legend in a list of dictionaries. Dictionary = {'img_url': <url>, 'description':
+        <description>}
+
+        """
+        return []
